@@ -20,7 +20,7 @@ EEE
 set -eu
 (
 cd `dirname $0`
-#sh ./extract.sh
+sh ./extract.sh
 sh ./prebuild.sh		#updが展開済みソースが必要だから。
 sh ./upd.sh
 
